@@ -118,25 +118,32 @@ Mojolicious::Plugin::RoutesAuthDBI::Guest - session for guests. Store guests in
 
     $app->plugin('RoutesAuthDBI', 
         ...
-        guest => {< options list below >},
+        guest => {< hashref options list below >},
         ...
     );
 
 =head1 OPTIONS
 
-=over 4
+=head2 namespace
 
-=item * B<namespace> - default 'Mojolicious::Plugin::RoutesAuthDBI',
+String, default to 'Mojolicious::Plugin::RoutesAuthDBI'.
 
-=item * B<module> - default 'Guest' (this module),
+=head2 module
 
-=item * B<session_key> - session storage of guest data. Default 'guest_data'.
+String, default to 'Guest' (this module).
 
-=item * B<stash_key> - 
+=head2 session_key
 
-=item * B<> - 
+String, session storage of guest data. Default to 'guest_data'.
+
+=head2 tables
+
+Hashref, any DB tables names. See L<Mojolicious::Plugin::RoutesAuthDBI::Schema#Default-variables-for-SQL-templates>.
+
+=head2 table
+
+String, DB table B<guests> name. See L<Mojolicious::Plugin::RoutesAuthDBI::Schema#Default-variables-for-SQL-templates>.
 
-=back
 
 =head1 METHODS
 
